<?xml version="1.0"?>
<!DOCTYPE schema SYSTEM "urn:x-commerceone:document:com:commerceone:xdk:xml:schema.dtd$1.0">

<schema uri="urn:x-commerceone:document:com:commerceone:CBL:CBL.sox$1.0" >

<intro>
<p>Copyright Notice</p>
<p>Common Business Library 2.0<br/>
Copyright 1999 Commerce One, Inc.</p>
<p>Permission is granted to use, copy, modify and distribute the DTD's, schemas
and modules in the Commerce One Common Business Library Version 2.0 subject to the terms
and conditions specified at http://www.marketsite.net/xml/cbl/copyright.html</p> 
</intro>

	<!-- 
		An AllowOrCharge is a credit or fee to be applied based
		on some criteria.

		The criteria may be based on the following:

		1. An optional date range.

		2. A quantity or monetary amount range.

		The AllowOrCharge may be a quantity (e.g. one gallon
		free if five gallons or more are purchased), a percentage,
		a monetary amount, or a tax.

		In normal usage, there may be many AllowOrCharge
		associated with a product.  The SeqNo field determines
		the order in which these are applied.
	 -->

	<elementtype name="AllowOrCharge">
	    <model>
	        <sequence>
	        	<!-- IsCharge is true if this describes
	        		a charge, false if it describes an allowance.  -->
		    	<element type="boolean" name="IsCharge" />
		    	
		    	<!-- The basis for this allowance or charge
		    		(quantity, percentage, monetary amount, or tax.)  -->
		    	<element type="AllowOrChgBasis" name="Basis"  />
		    	
				<!-- The calculation sequence indicator is used 
					when multiple allowances and/or charges are applicable. 
					If various allowances and/or charges percentages, 
					quantities, monetary amounts or rates are applicable 
					to the same base price, then the calculation sequence 
					indicator will always equal one. If the various 
					allowances and/or charges are applied against a 
					fluctuating price (constantly changing because of 
					the application of other allowances and/or charges) 
					then the sequence of calculation is indicated using 
					this data element.  Note that several allowances or
					charges may have the same sequence number, indicating
					they are applied to the same quantity.  -->
				<element type="int" name="SeqNo" />
		    	
		    	<!-- A description of what the allowance or
		    		charge is for.  -->

		    	<element type="AllowOrChgDesc" name="Desc" />

		    	<!-- The first date that this price applies.  If
		    		not specified, it defaults to a date in the distant
		    		future.   -->
		    	<element type="date" name="StartDate" occurs="?" />
		    	
		    	<!-- The last date that this price applies.  If
		    		not specified, it defaults to a date in the distant
		    		future.   -->
		    	<element type="date" name="EndDate" occurs="?" />

		    	
		    	<!-- The quantity or dollar amount for which
		    		this allowance or charge applies.  If not specified,
		    		this allowance or charge applies to all quantites.   -->
		    	<choice occurs="?">

					<!-- The quantity of this product that is
						required for this allowance or charge to apply.  -->
		    		<element type="QuantityRange"/>

					<!-- The money value of this product that is
						required for this allowance or charge to apply.  -->		    		
		    		<element type="MoneyRange"/>
		    		
		    	</choice>

		    	<!-- This allowance or charge may be for a quantity,
		    		a money amount, a percentage, or a tax amount.   -->
				<choice>						    	
			    	<!-- If the basis is Quantity, the quantity 
			    		value.  -->
			    	<element type="Quantity" occurs="?" />
			    	
			    	<!-- If the basis is Money, the money value.  -->
			    	<element type="Money" occurs="?" />
			    	
			    	<!-- If the basis is a Percent, the percentage
			    		value.  -->
			    	<element type="Decimal10_4" name="Percent" occurs="?" /> 
			    	
			    	<!-- If the basis is Tax, the Tax value.  -->
			    	<element type="Tax" occurs="?" />
			    </choice>	
			</sequence>
	    </model>
	</elementtype>
	
	<!-- The basis for an allowance or charge.  -->
	<datatype name="AllowOrChgBasis">
		<enumeration datatype="NMTOKEN">
			<option>None</option>
			<option>Quantity</option>
			<option>Percent</option>
			<option>Money</option>
			<option>Tax</option>
		</enumeration>
	</datatype>
	
	<!-- A container for a list of one or more AllowOrCharge  -->
	<elementtype name="ListOfAllowOrCharge">
    	<model>
    		<element type="AllowOrCharge" occurs="+" />
    	</model>
    </elementtype>
</schema>
