<?xml version="1.0"?>
<!DOCTYPE schema SYSTEM "urn:x-commerceone:document:com:commerceone:xdk:xml:schema.dtd$1.0">

<schema uri="urn:x-commerceone:document:com:commerceone:CBL:CBL.sox$1.0" >

<intro>
<p>Copyright Notice</p>
<p>Common Business Library 2.0<br/>
Copyright 1999 Commerce One, Inc.</p>
<p>Permission is granted to use, copy, modify and distribute the DTD's, schemas
and modules in the Commerce One Common Business Library Version 2.0 subject to the terms
and conditions specified at http://www.marketsite.net/xml/cbl/copyright.html</p> 
<h1>Errors</h1><p>
<![CDATA[

There are three level of errors that can happened when processing a request
document:

   1. Tranmission error, e.g.: HTTP timeout, etc.
   2. Document error,	e.g.: XML is not well formed, the instance does not
   				match the schema definition.
   3. Business Level error, e.g. : Invalid unit of measure.

The tranmission and document errors are not addressed using this module,
because it is specific to certain platform and XML run-time system.
The ErrorInfo module however, is designed to handle business level error.

ErrorInfo module should only be used under error condition. The existence of
this module signify that there is a business level error occured during 
processing of the request document. It contains the error code and optional
extra information related to the error.

For example, let say buyer B1 initiates a price check for 10 units of item 
SKU1 to supplier S1. Here are some possible result of the price check:

- successful				
- fail, due to invalid SKU number	(e.g. ErrorCode: PC_INVALID_SKU)
- fail, due to invalid quantity		(e.g. ErrorCode: PC_INVALID_QTY)
- fail, due to not enough availability	(e.g. ErrorCode: PC_INSUFFICIENT_QTY)

Each unique error condition has an Error Code assigned to it.
In addition to the error code, ErrorInfo can provide more information
to the caller. For example, for the case where the supplier does not have 
sufficient stock to satisfy customer's request, she can provide information
about how much stock it currently available.

The complete list of Error Code will be provided at seperate document.
	
]]>
</p></intro>

<datatype name="SeverityCode">
    <explain><p>Define the severity of an error. 
    		These enumeration is derived after evaluating various sources,
    		including IOTP 1.0 (Error Component section), 
    		CommerceOne, and other sources.
    	     </p>
    </explain>
    <enumeration datatype="NMTOKEN">
    	
        <option>Other</option><!-- This option should not be used under normal circumstances. -->
    	<option>Informational</option><!-- For caller information only -->
    	<option>Warning</option><!-- Non fatal error. -->
    	<option>Diagnostic</option><!-- For diag or debugging purposes -->
    	<option>Transient</option><!-- Errors are temporary in nature 
    		and request possibly can be resent in the future.
    		The interval before resend can occurs can be specified as
    		one of the parameters. -->
    	<option>Error</option><!-- A business error has occured. -->
    </enumeration>
</datatype>

<elementtype name="ErrorInfo" >
    <model>
	<sequence>
	    <!-- The complete list of error code is available elsewhere,
	    		specific to the message that use this module. -->
	    <element type="string" name="CompletionCode" />
	
	    <!--  The error message  -->
	    <element type="LangString" name="CompletionMsg" />
	    
	    <element type="SeverityCode" name="Severity" />

	    <!--  This optional field can be used to pass extra
	    		information to caller about an error.
	    		In a way, the motivation of this field is similar to 
	    		the IOTP's PackagedContent concept.
	    		For example, a buyer and a supplier can agree that
	    		under the situation where the supplier does not have
	    		enough stock, it will pass these three parameters:
	    			Param1	SKU#
	    			Param2  Buyer Requested Delivery Date
	    			Param3	The date when supplier will be able
	    				to fulfill the order
	     -->
	    <element type="ListOfParameter" occurs="?" />
	    
	    <!-- This optional field is used to specify the
	    		number of seconds that a caller has to wait before
	    		sending the retry request. This field is usually used
	    		by an error that has severity=Transient
	     -->
	    <element type="int" name="MinRetrySecs" occurs="?" />
	    
	    <!-- This optional Software Vendor Error Reference is
	    		used to specify the exact location where the
	    		error occurs. It should contain information that
	    		enable software vendor to trace back the exact
	    		location of the code that generate this code.
	     -->
	    <element type="string" name="SwVendorErrorRef" occurs="?" />
 
	</sequence>
    </model>
</elementtype>

<!--  container for Parameters  -->
<elementtype name="ListOfParameter">
	<model>
		<element type="string" name="Parameter" occurs="+" />
	</model>
</elementtype>

<!--  container for ErrorInfo  -->
<elementtype name="ListOfErrorInfo" >
    <model>
    	<element type="ErrorInfo" occurs="+" />
    </model>
</elementtype>

</schema>
