<?xml version="1.0"?>
<!DOCTYPE schema SYSTEM "urn:x-commerceone:document:com:commerceone:xdk:xml:schema.dtd$1.0">

<schema uri="urn:x-commerceone:document:com:commerceone:CBL:CBL.sox$1.0" >

<intro>
<p>Copyright Notice</p>
<p>Common Business Library 2.0<br/>
Copyright 1999 Commerce One, Inc.</p>
<p>Permission is granted to use, copy, modify and distribute the DTD's, schemas
and modules in the Commerce One Common Business Library Version 2.0 subject to the terms
and conditions specified at http://www.marketsite.net/xml/cbl/copyright.html</p> 
</intro>

<!-- 
This is based on the EANCOM's
PAI = Payment instructions
PAT = Payment term basis
EDI

Example: 2 % 10 net 30 Invoice Date
which means: 
The amount is due in 30 days from Invoice Day.
Take 2% off the amount if paid within 10 days.

PaymentMean 		= Invoice
PaymentTerm 		= Discount
DiscountPercent		= 2
DiscountDaysDue		= 10
PaymentTimeReference	= InvoiceDate
NetDaysDue		= 30
NetTimeRef		= InvoiceDate
 -->

<!--  PaymentMean name is taken from EDIFACT's PAI structure  -->
<datatype name="PaymentMeanCode">
    <explain><p>EDIFACT Data Element 4461. The payment type/mean.</p></explain>
    <enumeration datatype="NMTOKEN">
        <option>Other</option><!-- Mutually Defined -->
        <option>COD</option><!-- 10 In cash. Cash On Delivery (COD) -->
        <option>Check</option><!-- 20 Cheque -->
        <option>CreditCard</option><!-- 11E Credit Card (EAN Code) -->
        <option>DebitCard</option><!-- 12E Debit Card (EAN Code) -->
        <option>Invoice</option><!-- 13E Payment terms defined in invoice(EAN) -->
    </enumeration>
</datatype>

<datatype name="PaymentTermCode">
    <explain><p>EDIFACT Data Element 4279.The payment type qualifier.</p></explain>
    <enumeration datatype="NMTOKEN">
        <option>Other</option><!-- Mutually Defined,18 Previously agreed upon -->
        <option>Basic</option><!-- 1 Basic -->
        <option>FixedDate</option><!-- 3 Fixed date -->
        <option>BasicDiscount</option><!-- 8 Basic discount offered -->
        <option>Instant</option><!-- 10 Instant. Payment is due on receipt of invoice -->
        <option>Discount</option><!-- 22 Discount. Payment conditions related to discounts for advanced payments. -->
    </enumeration>
</datatype>

<datatype name="PaymentTimeReference">
    <enumeration datatype="NMTOKEN">
        <option>Other</option><!-- Mutually Defined -->
        <option>InvoiceDate</option><!-- 5 = Date of invoice -->
	<option>SpecifiedDate</option>
	<option>ShipmentDate</option><!-- 81 = Date of shipment as evidenced by the transport document(s) -->
	<option>GoodsReceivedByBuyerDate</option><!-- 21=Date goods received by buyer -->
	<option>TransportArrivalDate</option><!-- 26=Date of arrival of transport -->
    </enumeration>
</datatype>

<datatype name="CardTypeCode">
    <enumeration datatype="NMTOKEN">
        <option>Other</option><!-- Other Card Type -->
        <option>AMEX</option><!-- American Express -->
        <option>VISA</option><!-- VISA -->
        <option>MC</option><!-- Master Card -->
        <option>Discover</option><!-- Discover -->
        <option>JCB</option><!-- JCB -->
        <option>Diners</option><!-- Diners -->
    </enumeration>
</datatype>

<elementtype name="CardInfo">
    <model>
        <sequence>
            <!--  REF01 M	ID	2/2 E4 -  charge card number
	         REF02	M	AN	1/30 
	      	Recommended string length: AlphaNum17  -->
	    <element type="string" name="CardNum" />

	    <!--  REF01 M	ID	2/2 BB - authorization code
	         REF02	M	AN	1/30 
	     	Recommended string length: AlphaNum35  -->
	    <element type="string" name="CardAuthCode" occurs="?" />
		
	    <!--  REF01 M	ID	2/2 CR - customer reference number
		 REF02	M	AN	1/30 
		Recommended string length: AlphaNum35  -->
	    <!--  for transmission of customer-specific info with credit card  -->
	    <element type="string" name="CardRefNum" occurs="?" />
			
	    <!--  DTM01 M	ID	3/3 036 - charge card expiration date (conditional)
		 DTM02 C	DT	6/6	YYMMDD  -->
	    <element type="datetime"   name="CardExpirationDate" occurs="?" />

	    <!--  Amex, Visa, MC, etc. This is a required if
		payment type is credit card or debit card  -->
	    <element type="CardTypeCode" name="CardType" occurs="?" />
	    
	    <!--  CardTypeOther is specified only if CardType='Other' 
	    	Recommended string length: AlphaNum70  -->
	    <element type="string" name="CardTypeOther" occurs="?" />
			
	    <!--  C1 addition. Name printed on the card. Max 30 chars 
	    	Recommended string length: AlphaNum35  -->
	    <element type="string" name="CardHolderName" occurs="?" />
        </sequence>
    </model>
</elementtype>

<elementtype name="Payment">
    <model>
        <sequence>
            <!--   Indication of the instrument of payment   -->
	    <element type="PaymentMeanCode" name="PaymentMean" />
	    
	    <!--  PaymentMeanOther is specified if PaymentMean='Other' 
	    	Recommended string length: AlphaNum70  -->
	    <element type="string" name="PaymentMeanOther" occurs="?" />
	
	    <!--  Identification of the type of payment terms.  -->	
	    <element type="PaymentTermCode" name="PaymentTerm" />

	    <!--  PaymentTermOther is specified if PaymentTerm='Other' 
	    	Recommended string length: AlphaNum70  -->
	    <element type="string" name="PaymentTermOther" occurs="?" />	        
	    <element type="Decimal10_4" name="DiscountPercent" occurs="?" />
	    <element type="int" name="DiscountDaysDue" occurs="?" />
	    <element type="PaymentTimeReference" name="DiscountTimeRef" occurs="?" />
	    
	    <!--  Recommended string length: AlphaNum70  -->
	    <element type="string" name="DiscountTimeRefOther" occurs="?" />
	    
	    <!--  DiscountDueDate is rarely used. Most of the time,
	    	we will use the DiscountDaysDue + DiscountTimeRef  -->
	    <element type="datetime" name="DiscountDueDate" occurs="?" />

	    <element type="int" name="NetDaysDue" occurs="?" />
	    <element type="PaymentTimeReference" name="NetTimeRef" occurs="?" />
	    
	    <!--  Recommended string length: AlphaNum70  -->
	    <element type="string" name="NetTimeRefOther" occurs="?" />
            
            <!--  this field is required for credit/debit card payment type  -->
            <element type="CardInfo" occurs="?" />   	
	</sequence>
    </model>
</elementtype>
</schema>
