<?xml version="1.0"?>
<!DOCTYPE schema SYSTEM "urn:x-commerceone:document:com:commerceone:xdk:xml:schema.dtd$1.0">

<schema uri="urn:x-commerceone:document:com:commerceone:CBL:CBL.sox$1.0" >

<intro>
<p>Copyright Notice</p>
<p>Common Business Library 2.0<br/>
Copyright 1999 Commerce One, Inc.</p>
<p>Permission is granted to use, copy, modify and distribute the DTD's, schemas
and modules in the Commerce One Common Business Library Version 2.0 subject to the terms
and conditions specified at http://www.marketsite.net/xml/cbl/copyright.html</p> 
</intro>

<!-- 
This data structure is a subset of EDIFACT-based TDT=Transport Detail.
The direction will always be from Supplier To Buyer. The BuyerToSupplier direction
is reserved for future RMA feature.
 -->

<datatype name="TransportMode">
    <explain><p>Data Element 8067: Mode of transport, coded 
  		Coded method of transport used for the carriage of the goods. 
    	     </p>
    </explain>
    <enumeration datatype="NMTOKEN">
        <option>Other</option><!--  mutually defined  -->
    	<option>Maritime</option><!--  10 = Maritime / sea transport  -->
    	<option>Rail</option><!--  20 = Rail transport  -->
    	<option>Road</option><!--  30 = Road transport  -->
    	<option>Air</option><!--  40 = Air transport  -->
    	<option>Mail</option><!--  50 = Mail  -->
    	<option>Courier</option><!--  100 = Courier service (EAN Code)  -->
    </enumeration>
</datatype>

<datatype name="TransportMean">
    <explain>
    <p>The combination of
       Transport Mode and Transport Mean can be combined to form
       Data Element 8067 Mode of transport</p>
    </explain>
    <enumeration datatype="NMTOKEN">
    	<option>Other</option><!--  mutually defined  -->
    	<option>Standard</option>
    	<option>Express</option><!-- e.g.: Fedex Overnight  -->
    	<option>2Day</option><!-- e.g.: UPS 2nd Day Air  -->
    	<option>3Day</option><!-- e.g.: UPS 3 Day Select  -->
    	<option>BestPossible</option>
    	<option>NoPreference</option>
    </enumeration>
</datatype>

<datatype name="CarrierCode">
    <explain><p>Carrier Code</p></explain>
    <enumeration datatype="NMTOKEN">
    	<option>Other</option><!--  mutually defined  -->
    	<option>None</option>
    	<option>LessTruckLoadCarrier</option>
    	<option>CommonCarrier</option><!--  for truck load carrier  -->
    	<option>UPS</option><!-- United Parcel Service -->
    	<option>Fedex</option><!-- Federal Express -->
    	<option>DHL</option><!-- DHL -->
	<option>Airborne</option><!-- Airborne Express -->
    </enumeration>
</datatype>


<datatype name="TransitDirection">
    <explain><p>Data Element 8101: Transit direction, coded</p></explain>
    <enumeration datatype="NMTOKEN">
    	<option>BuyerToSupplier</option><!-- BS = Buyer to supplier -->
    	<option>SupplierToBuyer</option><!-- SB = Supplier to buyer -->
    </enumeration>
</datatype>

<elementtype name="Transport">
    <model>
    	<sequence>
      
	    <!--  Coded method of transport used for the 
	         carriage of the goods. -->
	    <element type="TransportMode" name="Mode" occurs="?" />
	    
	    <!--  A TransportModeOther is used only if the TransportMode is
	    	 'Other' 
	    	 Recommended string length: AlphaNum70  -->
	    <element type="string" name="TransportModeOther" occurs="?" />
	    
	    <!--  Code defining the type of the means of transport 
	         being utilized. -->
	    <element type="TransportMean" name="Mean" occurs="?" />
	    
	    <!--  A TransportMeanOther is used only if the TransportMean is
	    	 'Other' 
	    	 Recommended string length: AlphaNum70  -->
	    <element type="string" name="TransportMeanOther" occurs="?" />	 
	    	      
	    <!--  the carrier name, coded. This will be useful for future
	    	 advance ship notice, etc.  -->
	    <element type="CarrierCode" name="Carrier" occurs="?" /> 
	    
	    <!--  A CarrierOther is provided only if the Carrier is 'Other' 
	    	Recommended string length: AlphaNum70  -->
	    <element type="string" name="CarrierOther" occurs="?" />   
              
            <!--  Customers provided their shipping contract number to allow 
                 supplier to ship goods under specific freight conditions. 
                 Recommended string length: AlphaNum35  -->
            <element type="string" name="CustShippingContractNum" occurs="?" />
            
            <!--  Recommended string length: AlphaNum256  -->
            <element type="string" name="ShippingInstruction" occurs="?" />
            
        </sequence>
    </model>
   
    <!--  Most of the time it will be from supplier to buyer.
         In case of return, it will be from buyer to supplier  --> 
    <attdef datatype="TransitDirection" name="Direction" ><default>SupplierToBuyer</default></attdef>


</elementtype>
</schema>
